==> kie-internal-7.6.0.Final-sources.jar: org/kie/internal/jaxb/LocalDateTimeXmlAdapter.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package org.kie.internal.jaxb;

import java.time.DateTimeException;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.time.format.DateTimeFormatterBuilder;
import java.time.temporal.ChronoField;

import javax.xml.bind.annotation.adapters.XmlAdapter;

public class LocalDateTimeXmlAdapter extends XmlAdapter<String, LocalDateTime> {

    private final DateTimeFormatter formatter;

    public LocalDateTimeXmlAdapter() {
        formatter = new DateTimeFormatterBuilder()
                .appendPattern( "uuuu-MM-dd'T'HH:mm:ss" )
                .appendFraction( ChronoField.NANO_OF_SECOND, 0, 9, true )
                .toFormatter();
    }

    @Override
    public LocalDateTime unmarshal( String localDateTimeString ) throws Exception {
        if ( localDateTimeString == null ) {
            return null;
        }
        try {
            return LocalDateTime.from( formatter.parse( localDateTimeString ) );
        } catch ( DateTimeException e ) {
            throw new IllegalStateException( "Failed to convert string (" + localDateTimeString + ") to type ("
                    + LocalDateTime.class.getName() + ")." );
        }
    }

    @Override
    public String marshal( LocalDateTime localDateTimeObject ) throws Exception {
        if ( localDateTimeObject == null ) {
            return null;
        }
        return formatter.format( localDateTimeObject );
    }

}

==> kie-internal-9.44.0.Final-sources.jar: org/kie/internal/jaxb/LocalDateTimeXmlAdapter.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package org.kie.internal.jaxb;

import java.time.DateTimeException;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.time.format.DateTimeFormatterBuilder;
import java.time.temporal.ChronoField;

import jakarta.xml.bind.annotation.adapters.XmlAdapter;

public class LocalDateTimeXmlAdapter extends XmlAdapter<String, LocalDateTime> {

    private final DateTimeFormatter formatter;

    public LocalDateTimeXmlAdapter() {
        formatter = new DateTimeFormatterBuilder()
                .appendPattern( "uuuu-MM-dd'T'HH:mm:ss" )
                .appendFraction( ChronoField.NANO_OF_SECOND, 0, 9, true )
                .toFormatter();
    }

    @Override
    public LocalDateTime unmarshal( String localDateTimeString ) throws Exception {
        if ( localDateTimeString == null ) {
            return null;
        }
        try {
            return LocalDateTime.from( formatter.parse( localDateTimeString ) );
        } catch ( DateTimeException e ) {
            throw new IllegalStateException( "Failed to convert string (" + localDateTimeString + ") to type ("
                    + LocalDateTime.class.getName() + ")." );
        }
    }

    @Override
    public String marshal( LocalDateTime localDateTimeObject ) throws Exception {
        if ( localDateTimeObject == null ) {
            return null;
        }
        return formatter.format( localDateTimeObject );
    }

}
